#
# spec file for package python-azure-storage-blob
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%if 0%{?suse_version} >= 1500
%define skip_python2 1
%endif
Name:           python-azure-storage-blob
Version:        12.19.0
Release:        1.1
Summary:        Microsoft Azure Storage Blob Client Library for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/azure-storage-blob/azure-storage-blob-%{version}.tar.gz
BuildRequires:  %{python_module azure-nspkg >= 3.0.0}
BuildRequires:  %{python_module azure-storage-nspkg >= 3.0.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-azure-common >= 1.1.5
Requires:       python-azure-core < 2.0.0
Requires:       python-azure-core >= 1.28.0
Requires:       python-azure-nspkg >= 3.0.0
Requires:       python-azure-storage-common < 3.0.0
Requires:       python-azure-storage-common >= 2.1.0
Requires:       python-azure-storage-nspkg >= 3.0.0
Requires:       python-cryptography >= 2.1.4
Requires:       python-isodate >= 0.6.1
Requires:       (python-typing_extensions >= 4.3.0)
%if "%{python_flavor}" == "python2"
Requires:       python-futures
%endif
Conflicts:      python-azure-sdk <= 2.0.0
Conflicts:      python-azure-storage <= 0.36.0

BuildArch:      noarch

%python_subpackages

%description
Azure Blob storage is Microsoft's object storage solution for the cloud. Blob storage is optimized
for storing massive amounts of unstructured data, such as text or binary data.

Blob storage is ideal for:

* Serving images or documents directly to a browser
* Storing files for distributed access
* Streaming video and audio
* Storing data for backup and restore, disaster recovery, and archiving
* Storing data for analysis by an on-premises or Azure-hosted service

%prep
%setup -q -n azure-storage-blob-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/storage/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/storage/__pycache__
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
}

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/azure/storage/blob
%{python_sitelib}/azure_storage_blob-*.egg-info

%changelog
* Fri Nov 10 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.19.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Oct 11 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.18.3
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Sep 15 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.18.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Sep 13 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.18.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Remove unzip package from BuildRequires
- Switch source archive format to TAR.GZ
* Wed Jul 12 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.17.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Fri Apr 28 2023 Steve Kowalik <steven.kowalik@suse.com>
- Correct Requires on python-typing_extensions.
* Mon Apr 17 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.16.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Feb 23 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.15.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Wed Oct 19 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.14.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Oct 12 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.14.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Fri Aug  5 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.13.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Jul  8 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release (bsc#1202088, CVE-2022-30187)
  + Version 12.13.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed May 11 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.12.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Tue Mar 29 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.11.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Mar 10 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.10.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Rename LICENSE.txt to LICENSE in %%files section
- Update Requires from setup.py
* Mon Oct  4 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.9.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Fri May  7 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.8.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Mar 23 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.8.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Jan  7 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.7.0b1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Mon Nov 23 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.6.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Mon Oct  5 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.5.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Aug 26 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.4.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue May  5 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.3.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Rename HISTORY.md to CHANGELOG.md in %%files section
* Mon Jan 27 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 12.1.0
  + For detailed information about changes see the
    HISTORY.md file provided with this package
- Add unzip to BuildRequires
- Add missing HISTORY.md to %%files section
- Drop extra LICENSE.txt as upstream now ships its own
- Rename README.rst to README.md in %%files section
- Update Requires from setup.py
- Update %%description from README.md
* Fri Oct  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.1.0
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Drop patches to support older versions of setuptools as
  SLE-12 is now shipping with a recent enough version
  + asb_drop-compatible-releases-operator.patch
  + asb_drop-extras-require.patch
- Update Requires from setup.py
- Update %%description from setup.py
* Mon Apr 15 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.5.0
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Bump minimum version for namespace packages
  to 3.0.0 in BuildRequires and Requires
- Remove python-devel package from BuildRequires
- Remove unzip package from BuildRequires
- Refresh patches for new version
  + asb_drop-compatible-releases-operator.patch
  + asb_drop-extras-require.patch
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
- Update BuildRequires and Requires from setup.py
* Thu Oct  4 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 1.3.1
- Add patch to drop compatible releases operator from setup.py,
  required for SLES12 as the setuptools version is too old
  + asb_drop-compatible-releases-operator.patch
- Add patch to drop extras_require field from setup.py,
  required for SLES12 as the setuptools version is too old
  + asb_drop-extras-require.patch
